@@ -12,19 +12,18 @@ import tbump
 import tbump.config
 import tbump.git
 import tbump.init
-from tbump.config import Config
 from tbump.executor import Executor
 from tbump.file_bumper import FileBumper
 from tbump.git_bumper import GitBumper
 from tbump.hooks import HooksRunner
 
-TBUMP_VERSION = "6.2.0"
+TBUMP_VERSION = "6.3.0"
 
 USAGE = textwrap.dedent(
     """
 Usage:
   tbump [options] <new_version>
-  tbump [options] init <current_version>
+  tbump [options] init [--pyproject] <current_version>
   tbump --help
   tbump --version
 
@@ -35,27 +34,12 @@ Options:
    --non-interactive  Never prompt for confirmation. Useful for automated scripts.
    --dry-run          Only display the changes that would be made.
    --only-patch       Only patches files, skipping any git operations or hook commands.
+   --no-tag           Do not create a tag
+   --no-push          DO not push after creating the commit and/or tag
 """
 )
 
 
-class InvalidConfig(tbump.Error):
-    def __init__(
-        self,
-        io_error: Optional[IOError] = None,
-        parse_error: Optional[Exception] = None,
-    ):
-        super().__init__()
-        self.io_error = io_error
-        self.parse_error = parse_error
-
-    def print_error(self) -> None:
-        if self.io_error:
-            ui.error("Could not read config file:", self.io_error)
-        if self.parse_error:
-            ui.error("Invalid config:", self.parse_error)
-
-
 class Cancelled(tbump.Error):
     def print_error(self) -> None:
         ui.error("Cancelled by user")
@@ -63,11 +47,11 @@ class Cancelled(tbump.Error):
 
 @attr.s
 class BumpOptions:
-    working_path = attr.ib()  # type: Path
-    new_version = attr.ib()  # type: str
-    interactive = attr.ib(default=True)  # type: bool
-    dry_run = attr.ib(default=False)  # type: bool
-    only_patch = attr.ib(default=False)  # type: bool
+    working_path: Path = attr.ib()
+    new_version: str = attr.ib()
+    interactive: bool = attr.ib(default=True)
+    dry_run: bool = attr.ib(default=False)
+    only_patch: bool = attr.ib(default=False)
 
 
 def run(cmd: List[str]) -> None:
@@ -89,7 +73,10 @@ def run(cmd: List[str]) -> None:
 
     if opt_dict["init"]:
         current_version = opt_dict["<current_version>"]
-        tbump.init.init(working_path, current_version=current_version)
+        use_pyproject = opt_dict["--pyproject"]
+        tbump.init.init(
+            working_path, current_version=current_version, use_pyproject=use_pyproject
+        )
         return
 
     new_version = opt_dict["<new_version>"]
@@ -98,30 +85,25 @@ def run(cmd: List[str]) -> None:
         bump_options.dry_run = True
     if opt_dict["--non-interactive"]:
         bump_options.interactive = False
+
+    operations = ["patch", "hooks", "commit", "tag", "push"]
     if opt_dict["--only-patch"]:
-        bump_options.only_patch = True
-    bump(bump_options)
+        operations = ["patch"]
+    if opt_dict["--no-push"]:
+        operations.remove("push")
+    if opt_dict["--no-tag"]:
+        operations.remove("tag")
+    bump(bump_options, operations)
 
 
-def parse_config(working_path: Path) -> Config:
-    tbump_path = working_path / "tbump.toml"
-    try:
-        config = tbump.config.parse(tbump_path)
-    except IOError as io_error:
-        raise InvalidConfig(io_error=io_error)
-    except Exception as parse_error:
-        raise InvalidConfig(parse_error=parse_error)
-    return config
-
-
-def bump(options: BumpOptions) -> None:
+def bump(options: BumpOptions, operations: List[str]) -> None:
     working_path = options.working_path
     new_version = options.new_version
     interactive = options.interactive
-    only_patch = options.only_patch
     dry_run = options.dry_run
 
-    config = parse_config(options.working_path)
+    config_file = tbump.config.get_config_file(options.working_path)
+    config = config_file.get_config()
 
     # fmt: off
     ui.info_1(
@@ -130,13 +112,12 @@ def bump(options: BumpOptions) -> None:
     )
     # fmt: on
 
-    git_bumper = GitBumper(working_path)
+    git_bumper = GitBumper(working_path, operations)
     git_bumper.set_config(config)
     git_state_error = None
     try:
-        git_bumper.check_dirty()  # Avoid data loss
-        if not only_patch:
-            git_bumper.check_branch_state(new_version)
+        git_bumper.check_dirty()
+        git_bumper.check_branch_state(new_version)
     except tbump.git.GitError as e:
         if dry_run:
             git_state_error = e
@@ -144,16 +125,16 @@ def bump(options: BumpOptions) -> None:
             raise
 
     file_bumper = FileBumper(working_path)
-    file_bumper.set_config(config)
+    file_bumper.set_config_file(config_file)
 
-    hooks_runner = HooksRunner(working_path, config.current_version)
-    if not only_patch:
+    executor = Executor(new_version, file_bumper)
+
+    hooks_runner = HooksRunner(working_path, config.current_version, operations)
+    if "hooks" in operations:
         for hook in config.hooks:
             hooks_runner.add_hook(hook)
 
-    executor = Executor(new_version, file_bumper)
-    if not only_patch:
-        executor.add_git_and_hook_actions(new_version, git_bumper, hooks_runner)
+    executor.add_git_and_hook_actions(new_version, git_bumper, hooks_runner)
 
     if interactive:
         executor.print_self(dry_run=True)
@@ -170,10 +151,9 @@ def bump(options: BumpOptions) -> None:
         else:
             return
 
-    executor.print_self(dry_run=False)
     executor.run()
 
-    if config.github_url:
+    if config.github_url and "push" in operations:
         tag_name = git_bumper.get_tag_name(new_version)
         suggest_creating_github_release(config.github_url, tag_name)
 
